@@ -1,14 +1,14 @@
-mmds.2D.plot <- function (x, title = NULL, axis = c(1, 2), xlim = NULL, 
+mmds.2D.plot <- function (x,project = NULL, title = NULL, axis = c(1, 2), xlim = NULL, 
 ylim = NULL, outfile.type = NULL,
-outfile.name = "mmds",new.plot = TRUE, active.col = x$active.col[,3], 
-active.alpha = 1, sup.col = x$sup.col[,3], active.pch = 20, 
+outfile.name = "mmds",new.plot = TRUE, active.col = x$col[,3], 
+active.alpha = 1, sup.col = project$col[,3], active.pch = 20, 
 sup.pch = 3, active.lab = FALSE, sup.lab = FALSE, active.cex = 2, 
 sup.cex = 2, active.legend.cex = 2, sup.legend.cex = 2, 
 active.legend.lwd = 1, sup.legend.lwd = 2, active.lwd = 1, sup.lwd = 4, 
 legend = TRUE, active.legend.pos = "bottomleft",
-sup.legend.pos = "bottomright", active.legend.name = x$active.group[,1],
-sup.legend.name = x$sup.group[,1], active.legend.col = x$active.group[,2],
-sup.legend.col = x$sup.group[,2], outfile.width = NULL, outfile.height = NULL,
+sup.legend.pos = "bottomright", active.legend.name = x$group[,1],
+sup.legend.name = project$group[,1], active.legend.col = x$group[,2],
+sup.legend.col = project$group[,2], outfile.width = NULL, outfile.height = NULL,
 box.lwd = 1, cex.axis = 1, cex.lab = 1, sup.legend.text = 1,
 active.legend.text = 1, legend.axis = TRUE, grid = TRUE, axes = TRUE) {
 
@@ -17,36 +17,38 @@ active.legend.text = 1, legend.axis = TRUE, grid = TRUE, axes = TRUE) {
 		stop("object of class 'mmds' expected")
 	if (any(axis > length(x$eigen.perc)))
 		stop("wrong axis")
+	if(!is.null(project) && (!inherits(project, "project")))
+		stop("object of class 'project' expected")
 
 	#display eigenvalue percentages
 	if(legend.axis==TRUE){
-	x.lab <- paste("PC", axis[1], " (", x$eigen.perc[axis[1]], "%)", sep = "")
-	y.lab <- paste("PC", axis[2], " (", x$eigen.perc[axis[2]], "%)", sep = "")
+	x.lab <- paste("PC", axis[1], " (", round(x$eigen.perc[axis[1]],1), "%)", sep = "")
+	y.lab <- paste("PC", axis[2], " (", round(x$eigen.perc[axis[2]],1), "%)", sep = "")
 	}
 	else{
 	x.lab<-""
 	y.lab<-""
 	}
 	if (is.null(xlim)) {
-		if (is.null(x$sup.coord)) {
-			x.min <- min(x$active.coord[, axis[1]])
-			x.max <- max(x$active.coord[, axis[1]])
+		if (is.null(project)) {
+			x.min <- min(x$coord[, axis[1]])
+			x.max <- max(x$coord[, axis[1]])
 		}
 		else {
-			x.min <- min(x$active.coord[, axis[1]], x$sup.coord[, axis[1]])
-			x.max <- max(x$active.coord[, axis[1]], x$sup.coord[, axis[1]])
+			x.min <- min(x$coord[, axis[1]], project$coord[, axis[1]])
+			x.max <- max(x$coord[, axis[1]], project$coord[, axis[1]])
 		}
 	xlim <- c(x.min, x.max) * 1.2
 	}
 
 	if (is.null(ylim)) {
-		if (is.null(x$sup.coord)) {
-			y.min <- min(x$active.coord[, axis[2]])
-			y.max <- max(x$active.coord[, axis[2]])
+		if (is.null(project)) {
+			y.min <- min(x$coord[, axis[2]])
+			y.max <- max(x$coord[, axis[2]])
 		}
 		else {
-			y.min <- min(x$active.coord[, axis[2]], x$sup.coord[, axis[2]])
-			y.max <- max(x$active.coord[, axis[2]], x$sup.coord[, axis[2]])
+			y.min <- min(x$coord[, axis[2]], project$coord[, axis[2]])
+			y.max <- max(x$coord[, axis[2]], project$coord[, axis[2]])
 		}
 	ylim <- c(y.min, y.max) * 1.2
 	}
@@ -88,30 +90,31 @@ active.legend.text = 1, legend.axis = TRUE, grid = TRUE, axes = TRUE) {
 }	  
 	}
 	#print active data
-	plot(x$active.coord[, axis[1]], x$active.coord[, axis[2]], col = alpha(active.col, active.alpha),
+	plot(x$coord[, axis[1]], x$coord[, axis[2]], col = alpha(active.col, active.alpha),
 		pch = active.pch, cex = active.cex, lwd = active.lwd, xlab = x.lab, ylab = y.lab, xlim = xlim,
-		ylim = ylim,cex.lab=cex.lab,main=title,frame=FALSE,xaxt="n",yaxt="n")
+		ylim = ylim,cex.lab=cex.lab,main=title,frame=FALSE,xaxt="n",yaxt="n",mgp=c(1.6,1.6,1.6))
 	if (axes == TRUE) {
 	  axis(1,lwd=box.lwd,cex.axis=cex.axis)
 	  axis(2,lwd=box.lwd,cex.axis=cex.axis)
 	}
 	if (active.lab)
-		text(x$active.coord[, axis[1]], y = x$active.coord[, axis[2]],
-			labels = rownames(x$active.coord), pos = 3, col = active.col)
+		text(x$coord[, axis[1]], y = x$coord[, axis[2]],
+			labels = rownames(x$coord), pos = 3, col = active.col)
 
 	if (legend)		
 		legend (active.legend.pos, bg = "white", active.legend.name, pch = active.pch, pt.cex = active.legend.cex,
 		  pt.lwd = active.legend.lwd, col=active.legend.col,title="Active data",cex=active.legend.text,box.lwd=box.lwd)
-    if(!is.null(x$sup.coord)) {
+    if(!is.null(project)) {
+    			
 		#print supplementary data
 		if (legend) 
 			legend (sup.legend.pos, bg = "white", sup.legend.name, pch = sup.pch,cex=sup.legend.text,
 			  pt.cex = sup.legend.cex, pt.lwd = sup.legend.lwd, col=sup.legend.col,title="Sup data",box.lwd=box.lwd)
-		points(x$sup.coord[, axis[1]], x$sup.coord[, axis[2]],
+		points(project$coord[, axis[1]], project$coord[, axis[2]],
 			col = sup.col, pch = sup.pch, cex = sup.cex, lwd = sup.lwd)
 		if (sup.lab)
-			text(x$sup.coord[, axis[1]], y = x$sup.coord[, axis[2]],
-				labels = rownames(x$sup.coord), pos = 3, col = sup.col)
+			text(project$coord[, axis[1]], y = project$coord[, axis[2]],
+				labels = rownames(project$coord), pos = 3, col = sup.col)
 			
 	}
 	#lastly because in the foreground
@@ -124,4 +127,4 @@ active.legend.text = 1, legend.axis = TRUE, grid = TRUE, axes = TRUE) {
 		dev.off()
 		print("File created")
 	}
-}
\ No newline at end of file
+}
